package com.datacloudsec.scan.tasks.scheduler.job.task;

import com.datacloudsec.scan.dao.AlarmlogMapper;
import com.datacloudsec.scan.dao.ConfigMapper;
import com.datacloudsec.scan.dao.DeviceGroupMapper;
import com.datacloudsec.scan.dao.DeviceMapper;
import com.datacloudsec.scan.dao.EngineMapper;
import com.datacloudsec.scan.dao.SysBugMapper;
import com.datacloudsec.scan.dao.SysscanInfoMapper;
import com.datacloudsec.scan.dao.TaskBaseMapper;
import com.datacloudsec.scan.dao.UserMapper;
import com.datacloudsec.scan.entity.Task;
import com.datacloudsec.scan.entity.User;
import com.datacloudsec.scan.service.IReport;
import com.datacloudsec.scan.service.ITask;
import com.datacloudsec.scan.service.impl.TaskService;
import com.datacloudsec.scan.tasks.scheduler.job.AlermJob;
import com.datacloudsec.scan.tasks.scheduler.job.SysLogJob;
import com.datacloudsec.utils.EntryResult;
import com.datacloudsec.utils.FtpUtil;
import com.datacloudsec.utils.IPUtil;
import com.datacloudsec.utils.InstanceUtil;
import com.datacloudsec.utils.JsonUtil;
import com.datacloudsec.utils.KafkaUtil;
import com.datacloudsec.utils.MybatisUtil;
import com.datacloudsec.utils.ObjectUtil;
import com.google.common.collect.Sets;
import java.text.SimpleDateFormat;
import java.util.Collections;
import java.util.Comparator;
import java.util.Date;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.Set;
import java.util.concurrent.locks.ReentrantLock;
import org.apache.commons.collections4.CollectionUtils;
import org.apache.commons.collections4.MapUtils;
import org.apache.commons.lang.StringUtils;
import org.apache.commons.lang.time.DateUtils;
import org.apache.ibatis.session.SqlSession;
import org.apache.log4j.Logger;

/* loaded from: com_datacloudsec_scan_tasks_scheduler_job_task.jar:com/datacloudsec/scan/tasks/scheduler/job/task/SysTask.class */
public class SysTask {
    private static final Logger LOG = Logger.getLogger(SysTask.class);
    private static ITask taskService = (ITask) InstanceUtil.newServiceInstance(TaskService.class);
    private static TaskBaseMapper taskBaseMapper = (TaskBaseMapper) InstanceUtil.newDaoInstance(TaskBaseMapper.class);
    private static SysscanInfoMapper sysscanInfo = (SysscanInfoMapper) InstanceUtil.newDaoInstance(SysscanInfoMapper.class);
    private static DeviceMapper deviceMapper = (DeviceMapper) InstanceUtil.newDaoInstance(DeviceMapper.class);
    private static EngineMapper engineMapper = (EngineMapper) InstanceUtil.newDaoInstance(EngineMapper.class);
    private static UserMapper userMapper = (UserMapper) InstanceUtil.newDaoInstance(UserMapper.class);
    private static DeviceGroupMapper deviceGroupMapper = (DeviceGroupMapper) InstanceUtil.newDaoInstance(DeviceGroupMapper.class);
    private static AlarmlogMapper alarmlogMapper = (AlarmlogMapper) InstanceUtil.newDaoInstance(AlarmlogMapper.class);
    private static ConfigMapper configMapper = (ConfigMapper) InstanceUtil.newDaoInstance(ConfigMapper.class);
    private static ReentrantLock lock = new ReentrantLock();

    public static void sysScanSync(Task task, Map<String, Object> results) {
        String error;
        if (task == null) {
            return;
        }
        lock.lock();
        try {
            try {
                User user = userMapper.getUserById(task.getUid());
                int offset1 = ObjectUtil.getInt(task.getOffset1(), 0);
                int offset2 = ObjectUtil.getInt(task.getOffset2(), 0);
                Map<String, Object> result = results.containsKey("result") ? (Map) results.get("result") : results;
                int totalProgress = ObjectUtil.getInt(result.get("progress"), 0);
                String errorSum = ObjectUtil.getString(results.get("error"), (String) null);
                List<Map<String, Object>> hostsRes = (List) result.get("hosts");
                if (CollectionUtils.isNotEmpty(hostsRes)) {
                    Collections.sort(hostsRes, new Comparator<Map<String, Object>>() { // from class: com.datacloudsec.scan.tasks.scheduler.job.task.SysTask.1
                        @Override // java.util.Comparator
                        public int compare(Map<String, Object> a, Map<String, Object> b) {
                            return ObjectUtil.getString(a.get("host"), "").toUpperCase().compareTo(ObjectUtil.getString(b.get("host"), "").toUpperCase());
                        }
                    });
                }
                Set<Map<String, Object>> hoststemp = hostsRes == null ? Sets.newLinkedHashSet() : Sets.newLinkedHashSet(hostsRes);
                Map<String, Map<String, Object>> hosts = new HashMap<>();
                if (CollectionUtils.isNotEmpty(hoststemp)) {
                    Map<String, Object> ipDevidMap = EntryResult.parseEntry(taskBaseMapper.getDevIdIpByTaskid(task.getId()), "ip", "deviceid");
                    Map<String, String> hostAlreadyMap = new HashMap<>();
                    List<String> ips = taskBaseMapper.getTaskIpByTid(task.getId());
                    Map<String, Object> progressMap = new HashMap<>();
                    for (Map<String, Object> host : hoststemp) {
                        String ip = ObjectUtil.getString(host.get("host"), "");
                        host.put("system", ObjectUtil.getString(host.get("system"), "", 65535));
                        String startTime = ObjectUtil.getString(host.get("startTime"), "");
                        String endTime = ObjectUtil.getString(host.get("endTime"), "");
                        String[] parsePatterns = {"yyyy-MM-dd HH:mm:ss.S", "yyyy-MM-dd", "yyyy-MM-dd HH:mm:ss"};
                        try {
                            host.put("startTime", "".equals(startTime) ? null : DateUtils.parseDate(startTime, parsePatterns));
                            host.put("endTime", "".equals(endTime) ? null : DateUtils.parseDate(endTime, parsePatterns));
                        } catch (Exception e) {
                            LOG.error("引擎响应的时间格式错误");
                        }
                        progressMap.put(ip, ObjectUtil.getInt(host.get("progress"), 0) > ObjectUtil.getInt(progressMap.get(ip), 0) ? host.get("progress") : progressMap.get(ip));
                        if (ObjectUtil.getInt(host.get("progress"), 0) == 0) {
                            host.put("progress", progressMap.get(ip));
                        }
                        if (!ips.contains(ip) && !hostAlreadyMap.containsKey(ip)) {
                            String hostIps = "";
                            if (StringUtils.isNotBlank(task.getVal3())) {
                                List<Map<String, Object>> ipList = (List) JsonUtil.MAPPER.readValue(task.getVal3(), List.class);
                                Iterator<Map<String, Object>> it = ipList.iterator();
                                while (true) {
                                    if (!it.hasNext()) {
                                        break;
                                    }
                                    Map<String, Object> ipMap = it.next();
                                    String currentIps = ObjectUtil.getString(ipMap.get("name"), "");
                                    if (StringUtils.isNotBlank(currentIps) && IPUtil.ipVaild(ip, currentIps)) {
                                        hostIps = currentIps;
                                        break;
                                    }
                                }
                            }
                            String config = sysscanInfo.getValueByName("sysscan_auth_" + task.getId());
                            Object auths = null;
                            if (StringUtils.isNotBlank(config)) {
                                auths = JsonUtil.MAPPER.readValue(config, Object.class);
                            }
                            Map<String, Object> sysDevMap = null;
                            if (auths != null) {
                                Map<String, Object> auth = null;
                                if (auths instanceof Map) {
                                    auth = (Map) auths;
                                } else if (auths instanceof List) {
                                    auth = (Map) EntryResult.parseEntryMap((List) auths, "ip").get(ip);
                                }
                                if (auth != null && auth.size() > 0) {
                                    sysDevMap = deviceMapper.getDevForSys(ObjectUtil.getInt(auth.get("id")));
                                    if (sysDevMap != null) {
                                        Map<String, Object> devGroup = deviceGroupMapper.getDevGroupById(ObjectUtil.getInt(sysDevMap.get("dgid")));
                                        sysDevMap.put("name", String.valueOf(ObjectUtil.getString(sysDevMap.get("name"), "")) + " " + ObjectUtil.getString(sysDevMap.get("ip"), "") + " 【主机】");
                                        sysDevMap.put("devgroup", ObjectUtil.getString(devGroup.get("name"), ""));
                                        sysDevMap.put("type", 0);
                                        sysDevMap.put("taskId", task.getId());
                                        sysDevMap.put("hostId", task.getHostId());
                                        sysDevMap.put("status", 1);
                                        sysDevMap.put("ips", hostIps);
                                        sysDevMap.put("confContent", JsonUtil.MAPPER.writeValueAsString(auth));
                                        sysDevMap.put("id", ipDevidMap.get(ObjectUtil.getString(sysDevMap.get("ip"), "")));
                                        taskBaseMapper.insertSysTaskDevice(sysDevMap);
                                    } else {
                                        sysDevMap = new HashMap<>();
                                        sysDevMap.put("type", 0);
                                        sysDevMap.put("taskId", task.getId());
                                        sysDevMap.put("hostId", task.getHostId());
                                        sysDevMap.put("name", String.valueOf(ip) + "【主机】");
                                        sysDevMap.put("ip", ip);
                                        sysDevMap.put("regionSid", Integer.valueOf((user == null || user.getRegionSid() == null) ? 110000 : user.getRegionSid().intValue()));
                                        sysDevMap.put("regionCid", Integer.valueOf((user == null || user.getRegionCid() == null) ? 110101 : user.getRegionCid().intValue()));
                                        sysDevMap.put("status", 1);
                                        sysDevMap.put("ips", hostIps);
                                        sysDevMap.put("id", ipDevidMap.get(ip));
                                        taskBaseMapper.insertSysTaskDevice(sysDevMap);
                                    }
                                } else {
                                    auths = null;
                                }
                            }
                            if (auths == null) {
                                sysDevMap = new HashMap<>();
                                sysDevMap.put("type", 0);
                                sysDevMap.put("taskId", task.getId());
                                sysDevMap.put("hostId", task.getHostId());
                                sysDevMap.put("name", ip);
                                sysDevMap.put("ip", ip);
                                sysDevMap.put("regionSid", Integer.valueOf((user == null || user.getRegionSid() == null) ? 110000 : user.getRegionSid().intValue()));
                                sysDevMap.put("regionCid", Integer.valueOf((user == null || user.getRegionCid() == null) ? 110101 : user.getRegionCid().intValue()));
                                sysDevMap.put("status", 1);
                                sysDevMap.put("ips", hostIps);
                                sysDevMap.put("id", ipDevidMap.get(ip));
                                taskBaseMapper.insertSysTaskDevice(sysDevMap);
                            }
                            host.put("deviceid", ObjectUtil.getInt(sysDevMap.get("id")));
                        }
                        hostAlreadyMap.put(ip, ip);
                        Map<String, Object> dev = taskBaseMapper.getTaskDevByTidAndIp(task.getId(), ip);
                        if (dev != null) {
                            host.put("deviceid", ObjectUtil.getInt(dev.get("id")));
                        }
                        if (ObjectUtil.getInt(host.get("deviceid")) != null) {
                            host.put("taskId", task.getId());
                            try {
                                Map<String, Object> hostInfo = engineMapper.getHostByDevid(ObjectUtil.getInt(host.get("deviceid")));
                                if (MapUtils.isNotEmpty(hostInfo)) {
                                    String portStr = ObjectUtil.getString(hostInfo.get("ports"), "");
                                    if (StringUtils.isNotBlank(portStr)) {
                                        Set<Map<String, Object>> portSet = Sets.newHashSet((Iterable) JsonUtil.MAPPER.readValue(portStr, List.class));
                                        List<Map<String, Object>> newPortList = (List) host.get("ports");
                                        if (CollectionUtils.isNotEmpty(newPortList)) {
                                            Set<Map<String, Object>> newPorts = Sets.newHashSet(newPortList);
                                            portSet.addAll(newPorts);
                                        }
                                        host.put("ports", JsonUtil.MAPPER.writeValueAsString(portSet));
                                    } else {
                                        host.put("ports", host.get("ports") == null ? "" : JsonUtil.MAPPER.writeValueAsString(host.get("ports")));
                                    }
                                    if (StringUtils.isBlank(ObjectUtil.getString(host.get("system"), ""))) {
                                        host.put("system", hostInfo.get("system"));
                                    }
                                    if (host.get("startTime") == null) {
                                        host.put("startTime", hostInfo.get("startTime"));
                                    }
                                    if (host.get("endTime") == null) {
                                        host.put("endTime", hostInfo.get("endTime"));
                                    }
                                    if (StringUtils.isBlank(ObjectUtil.getString(host.get("mac"), ""))) {
                                        host.put("mac", hostInfo.get("mac"));
                                    }
                                } else {
                                    host.put("ports", host.get("ports") == null ? "" : JsonUtil.MAPPER.writeValueAsString(host.get("ports")));
                                }
                            } catch (Exception e2) {
                                LOG.error("端口解析失败：" + e2);
                            }
                            engineMapper.sysAddHost(host);
                            hosts.put(ip, host);
                        }
                    }
                }
                Map<String, List<Map<String, Object>>> bugMap = EntryResult.parseEntryListMap((List) result.get("vuls"), "host");
                Map<String, Map<String, Object>> errorsMap = EntryResult.parseEntryMap((List) result.get("errs"), "host");
                int totalBugSize = 0;
                int totalErrSize = 0;
                String topic = configMapper.getValueByName("kafka_topic");
                String address = configMapper.getValueByName("kafka_address");
                List<Map<String, Object>> devices = taskBaseMapper.getTaskDevByTid(task.getId());
                for (Map<String, Object> device : devices) {
                    if (ObjectUtil.getInt(device.get("status"), 0) == 1) {
                        SqlSession session = null;
                        try {
                            try {
                                String ip2 = ObjectUtil.getString(device.get("ip"), "");
                                List<Map<String, Object>> vuls = bugMap.get(ip2);
                                totalBugSize += vuls == null ? 0 : vuls.size();
                                Integer deviceid = ObjectUtil.getInt(device.get("id"));
                                SqlSession session2 = MybatisUtil.sqlSessionFactory.openSession(true);
                                EngineMapper engMapper = (EngineMapper) session2.getMapper(EngineMapper.class);
                                SysBugMapper sysBugMapper = (SysBugMapper) session2.getMapper(SysBugMapper.class);
                                Map<String, Object> errMap = errorsMap.get(ip2);
                                if (MapUtils.isNotEmpty(errMap)) {
                                    totalErrSize++;
                                    errMap.put("deviceid", deviceid);
                                    errMap.put("taskId", task.getId());
                                    engMapper.sysAddErr(errMap);
                                    error = ObjectUtil.getString(errMap.get("detail"), "");
                                } else {
                                    error = errorSum;
                                }
                                if (CollectionUtils.isNotEmpty(vuls)) {
                                    engMapper.sysAddVuls1(deviceid, task.getId(), vuls);
                                    if (StringUtils.isNotBlank(topic) && StringUtils.isNotBlank(address)) {
                                        String[] oids = new String[vuls.size()];
                                        int len = vuls.size();
                                        for (int i = 0; i < len; i++) {
                                            oids[i] = ObjectUtil.getString(vuls.get(i).get("oid"), "");
                                        }
                                        List<Map<String, Object>> bugs = sysBugMapper.getBugsByOids(oids);
                                        for (Map<String, Object> b : bugs) {
                                            try {
                                                Map<String, Object> data = new HashMap<>();
                                                data.put("bug_id", ObjectUtil.getString(b.get("oid"), ""));
                                                data.put("bug_name", ObjectUtil.getString(b.get("name"), ""));
                                                data.put("bug_desct", ObjectUtil.getString(b.get("desct"), ""));
                                                data.put("bug_ip", ip2);
                                                data.put("bug_type", ObjectUtil.getString(b.get("old_family"), ""));
                                                data.put("bug_level", ObjectUtil.getString(b.get("level"), ""));
                                                data.put("bug_status", 1);
                                                KafkaUtil.getInstance().send(data);
                                            } catch (Exception e3) {
                                                LOG.error("kafka发送失败：", e3);
                                            }
                                        }
                                    }
                                }
                                Map<String, Object> host2 = MapUtils.isEmpty(hosts) ? new HashMap<>() : hosts.get(ip2);
                                int progress = MapUtils.isEmpty(host2) ? 0 : ObjectUtil.getInt(host2.get("progress"), 0);
                                Integer status = null;
                                if (progress == 100) {
                                    status = 2;
                                    Map<String, Object> sys = sysBugMapper.bugCountByDev(deviceid);
                                    Date time = new Date();
                                    sysBugMapper.insertSysStatics(1, Integer.valueOf(ObjectUtil.getInt(sys.get("h"), 0)), time, deviceid, ip2, task.getId());
                                    sysBugMapper.insertSysStatics(2, Integer.valueOf(ObjectUtil.getInt(sys.get("m"), 0)), time, deviceid, ip2, task.getId());
                                    sysBugMapper.insertSysStatics(3, Integer.valueOf(ObjectUtil.getInt(sys.get("l"), 0)), time, deviceid, ip2, task.getId());
                                    sysBugMapper.insertSysStatics(4, Integer.valueOf(ObjectUtil.getInt(sys.get("i"), 0)), time, deviceid, ip2, task.getId());
                                    sysBugMapper.updDidByTidAndIp(deviceid, task.getId(), ip2);
                                    SysLogJob.addBugs(sysBugMapper.getBugsForLog(deviceid));
                                    FtpUtil.reportUpload(task, device, (String) IReport.REPORT_CHK.get("sys"), "sys");
                                }
                                if (StringUtils.isNotBlank(error)) {
                                    status = 3;
                                }
                                engMapper.updateScanInfo(deviceid, status, Double.valueOf(progress), (Integer) null, (Integer) null, error == null ? "" : error, Integer.valueOf(offset1 + (vuls == null ? 0 : vuls.size())), Integer.valueOf(offset2 + (errMap == null ? 0 : 1)), (Integer) null, new Date(), false);
                                session2.commit();
                                if (session2 != null) {
                                    session2.close();
                                }
                            } catch (Exception e1) {
                                if (0 != 0) {
                                    session.rollback();
                                }
                                LOG.error("系统引擎同步出错", e1);
                                if (0 != 0) {
                                    session.close();
                                }
                            }
                        } catch (Throwable th) {
                            if (0 != 0) {
                                session.close();
                            }
                            throw th;
                        }
                    }
                }
                if (totalProgress == 100) {
                    task.setOffset1(Integer.valueOf(offset1 + totalBugSize));
                    task.setOffset2(Integer.valueOf(offset2 + totalErrSize));
                    task.setStatus(2);
                    task.setEndTime(new SimpleDateFormat("yyyy-MM-dd HH:mm:ss").format(new Date()));
                    taskBaseMapper.updateSysTask(task);
                    engineMapper.updStatusByTaskId(task.getId(), 2);
                    List<Map<String, Object>> devs = engineMapper.getDevByTaskId(task.getId());
                    if (CollectionUtils.isNotEmpty(devs)) {
                        engineMapper.insertTaskIp(task.getId(), devs);
                    }
                    if (task.getAlarmType().intValue() == 1) {
                        AlermJob.alermTask(task.getId());
                    }
                    Task waitingTask = engineMapper.getWaitingSysTask(1, task.getId());
                    if (waitingTask != null) {
                        taskService.startTask(waitingTask.getId());
                    }
                    alarmLog(task.getId());
                    if (StringUtils.isNotBlank(topic) && StringUtils.isNotBlank(address)) {
                        Map<String, Object> data2 = new HashMap<>();
                        data2.put("task_ip", sysscanInfo.getValueByName("sysscan_ip_" + task.getId()));
                        KafkaUtil.getInstance().send(data2);
                    }
                } else {
                    task.setOffset1(Integer.valueOf(offset1 + totalBugSize));
                    task.setOffset2(Integer.valueOf(offset2 + totalErrSize));
                    taskBaseMapper.updateSysTask(task);
                }
            } catch (Exception e4) {
                LOG.error("系统引擎同步出错", e4);
                lock.unlock();
            }
        } finally {
            lock.unlock();
        }
    }

    private static void alarmLog(Integer taskId) throws Exception {
        List<Map<String, Object>> querySysBug = alarmlogMapper.querySysBug(taskId);
        if (CollectionUtils.isNotEmpty(querySysBug)) {
            alarmlogMapper.delAlarmlogByTime();
            alarmlogMapper.batchInsert(querySysBug);
        }
    }
}
